<?php
namespace JLTDFSM;

use JLTDFSM\Libs\Assets;
use JLTDFSM\Libs\Helper;
use JLTDFSM\Libs\Featured;
use JLTDFSM\Inc\Classes\Recommended_Plugins;
use JLTDFSM\Inc\Classes\Notifications\Notifications;
use JLTDFSM\Inc\Classes\Pro_Upgrade;
use JLTDFSM\Inc\Classes\Row_Links;
use JLTDFSM\Inc\Classes\Upgrade_Plugin;
use JLTDFSM\Inc\Admin\AdminSettings;
use JLTDFSM\Inc\Classes\Feedback;

/**
 * Main Class
 *
 * @Disable Fullscreen Mode
 * Jewel Theme <support@jeweltheme.com>
 * @version     1.0.3
 */

// No, Direct access Sir !!!
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Disable_Fullscreen_Mode Class
 */
if ( ! class_exists( '\JLTDFSM\Disable_Fullscreen_Mode' ) ) {

	/**
	 * Class: Disable_Fullscreen_Mode
	 */
	final class Disable_Fullscreen_Mode {

		const VERSION            = JLTDFSM_VER;
		private static $instance = null;

		/**
		 * what we collect construct method
		 *
		 * @author Jewel Theme <support@jeweltheme.com>
		 */
		public function __construct() {
			$this->includes();
			add_action( 'plugins_loaded', array( $this, 'jltdfsm_plugins_loaded' ), 999 );
			// Body Class.
			add_filter( 'admin_body_class', array( $this, 'jltdfsm_body_class' ) );
			// This should run earlier .
			// add_action( 'plugins_loaded', [ $this, 'jltdfsm_maybe_run_upgrades' ], -100 ); .
			add_action( 'enqueue_block_editor_assets', [$this, 'jltdfsm_disable_default_fullscreen_mode' ], 99 );
		}

		/**
		 * Disable Fullscreen Editor
		 *
		 * @return void
		 * @author Jewel Theme <support@jeweltheme.com>
		 */
		public function jltdfsm_disable_default_fullscreen_mode(){
			if (is_admin()) {
				$script = "jQuery( window ).load(function() { const isFullscreenMode = wp.data.select( 'core/edit-post' ).isFeatureActive( 'fullscreenMode' ); if ( isFullscreenMode ) { wp.data.dispatch( 'core/edit-post' ).toggleFeature( 'fullscreenMode' ); } });";
	    		wp_add_inline_script( 'wp-blocks', $script );
			}
		}


		/**
		 * plugins_loaded method
		 *
		 * @author Jewel Theme <support@jeweltheme.com>
		 */
		public function jltdfsm_plugins_loaded() {
			$this->jltdfsm_activate();
		}

		/**
		 * Version Key
		 *
		 * @author Jewel Theme <support@jeweltheme.com>
		 */
		public static function plugin_version_key() {
			return Helper::jltdfsm_slug_cleanup() . '_version';
		}

		/**
		 * Activation Hook
		 *
		 * @author Jewel Theme <support@jeweltheme.com>
		 */
		public static function jltdfsm_activate() {
			$current_jltdfsm_version = get_option( self::plugin_version_key(), null );

			if ( get_option( 'jltdfsm_activation_time' ) === false ) {
				update_option( 'jltdfsm_activation_time', strtotime( 'now' ) );
			}

			if ( is_null( $current_jltdfsm_version ) ) {
				update_option( self::plugin_version_key(), self::VERSION );
			}

			$allowed = get_option( Helper::jltdfsm_slug_cleanup() . '_allow_tracking', 'no' );

			// if it wasn't allowed before, do nothing .
			if ( 'yes' !== $allowed ) {
				return;
			}
			// re-schedule and delete the last sent time so we could force send again .
			$hook_name = Helper::jltdfsm_slug_cleanup() . '_tracker_send_event';
			if ( ! wp_next_scheduled( $hook_name ) ) {
				wp_schedule_event( time(), 'weekly', $hook_name );
			}
		}


		/**
		 * Add Body Class
		 *
		 * @param [type] $classes .
		 *
		 * @author Jewel Theme <support@jeweltheme.com>
		 */
		public function jltdfsm_body_class( $classes ) {
			$classes .= ' disable-fullscreen-mode ';
			return $classes;
		}

		/**
		 * Run Upgrader Class
		 *
		 * @return void
		 */
		public function jltdfsm_maybe_run_upgrades() {
			if ( ! is_admin() && ! current_user_can( 'manage_options' ) ) {
				return;
			}

			// Run Upgrader .
			$upgrade = new Upgrade_Plugin();

			// Need to work on Upgrade Class .
			if ( $upgrade->if_updates_available() ) {
				$upgrade->run_updates();
			}
		}

		/**
		 * Include methods
		 *
		 * @author Jewel Theme <support@jeweltheme.com>
		 */
		public function includes() {
			new Assets();
			new Recommended_Plugins();
			new Row_Links();
			new Pro_Upgrade();
			new Notifications();
			new Featured();
			new Feedback();
		}


		/**
		 * Initialization
		 *
		 * @author Jewel Theme <support@jeweltheme.com>
		 */
		public function jltdfsm_init() {
			$this->jltdfsm_load_textdomain();
		}


		/**
		 * Text Domain
		 *
		 * @author Jewel Theme <support@jeweltheme.com>
		 */
		public function jltdfsm_load_textdomain() {
			$domain = 'disable-fullscreen-mode';
			$locale = apply_filters( 'jltdfsm_plugin_locale', get_locale(), $domain );

			load_textdomain( $domain, WP_LANG_DIR . '/' . $domain . '/' . $domain . '-' . $locale . '.mo' );
			load_plugin_textdomain( $domain, false, dirname( JLTDFSM_BASE ) . '/languages/' );
		}




		/**
		 * Returns the singleton instance of the class.
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Disable_Fullscreen_Mode ) ) {
				self::$instance = new Disable_Fullscreen_Mode();
				self::$instance->jltdfsm_init();
			}

			return self::$instance;
		}
	}

	// Get Instant of Disable_Fullscreen_Mode Class .
	Disable_Fullscreen_Mode::get_instance();
}